@@ -15,17 +15,29 @@ MainWindow::MainWindow(QWidget *parent) :
 
 
 {
+    system("mkdir /home/user/MyDocs/.images/desktop+ & mv /home/*.png /home/user/MyDocs/.images/desktop+/");
+
+    QString helpText;
+
+    helpText.append(tr("<h3>Erste Schritte:") +"</h3>");
+    helpText.append(tr("(1) Mindestens 'Matan's modified-hildon-desktop' muss installiert sein um zustzliche Desktops zu aktivieren.")+"<br/>");
+    helpText.append(tr("<p>(2) Die Hintergrnde mssen unter <b>/home/user/MyDocs/.images/desktop+/ liegen<br/>und 1.png - 9.png heien.</b>"));
+
+    QMessageBox::about(this, tr("Desktop+"),
+                       helpText);
 
     ui->setupUi(this);
     connect(ui->actionHelp, SIGNAL(triggered()), this, SLOT(showHelp()));
     connect(ui->actionAbout, SIGNAL(triggered()), this, SLOT(showAbout()));
     connect(ui->actionInstall, SIGNAL(triggered()), this, SLOT(showInstall()));
-    connect(ui->actionInstall2, SIGNAL(triggered()), this, SLOT(showInstall2()));
+    connect(ui->actionTest, SIGNAL(triggered()), this, SLOT(showTest()));
+
 
 }
 
 MainWindow::~MainWindow()
 {
+
     delete ui;
 }
 
@@ -33,10 +45,10 @@ void MainWindow::showHelp()
 {
     QString helpText;
 
-    helpText.append("<h2>Desktop+ "+tr("Hilfe") +"</h2>");
-    helpText.append("<p>"+ tr("vereinfacht das anlegen zustzlicher Desktops")+"<br/>");
-    helpText.append(tr("Der 'modified-hildon-desktop' muss installiert sein um zustzliche Desktops zu aktivieren.")+"<br/>");
-    helpText.append(tr("<h2>Die Hintergrnde mssen unter /home/user/MyDocs/.images/desktop+/ liegen und 1.png - 9.png heien.</h2>")+"<br/>");
+    helpText.append("<h3>Desktop+ "+tr("Hilfe") +"</h3>");
+    helpText.append("<p>"+ tr("...vereinfacht das anlegen zustzlicher Desktops")+"<br/>");
+    helpText.append(tr("'Matan's modified-hildon-desktop' muss installiert sein um zustzliche Desktops zu aktivieren.")+"<br/>");
+    helpText.append(tr("<h3>Die Hintergrnde mssen unter /home/user/MyDocs/.images/desktop+/ liegen und 1.png - 9.png heien.</h3>")+"<br/>");
     QMessageBox::about(this, tr("Hilfe"),
                        helpText);
 }
@@ -44,9 +56,9 @@ void MainWindow::showHelp()
 void MainWindow::showAbout()
 {
     QString about;
-    about.append("<h2>Desktop+</h2>");
+    about.append("<h3>Desktop+</h3>");
     about.append(tr("Entwickelt in Qt %1<br/>").arg(QString(QT_VERSION_STR)));
-    about.append(tr("Copyright") + " 2010 - &lt;NightShift79@meego.de&gt;<br/><br/>");
+    about.append(tr("Copyright") + " 2010 - &lt;NightShift79@highspeed3.de&gt;<br/><br/>");
 
     QMessageBox::about(this, tr("ber Desktop+"),
                        about);
@@ -55,24 +67,23 @@ void MainWindow::showAbout()
 void MainWindow::showInstall()
 {
     QString mhd;
-    mhd.append("ber den Link installieren:");
-        mhd.append(tr("<h1><a href=http://my.arava.co.il/~matan/770/n900/m-h-d.install>modified-hildon-desktop</a><br/></h1></p>"));
+    mhd.append("<p>"+ tr("<br/><h3>Ein modifizierter hildon-desktop wird bentigt!</h3>")+"");
+    mhd.append("<p>"+ tr("ber den untenstehenden Link kann die neuste, inoffizielle version von MohammadAGs hildon-desktop runtergeladen werden.")+"<br/>"+("Dieser mu mittels 'dpgk -i' im Terminal installiert werden.")+"<br/>");
+    mhd.append("Diese Version beinhaltet neben einigen Verbesserungen auch alle features on Matans modified-hildon-desktop.");
+    mhd.append(tr("<h3><a href=http://mohammadag.xceleo.org/public/maemo/debfiles/matan/hildon-desktop_2.2.138-1+0m5_armel.deb>modified-hildon-desktop</a></h3></p>"));
 
-        QMessageBox::about(this, tr("modified-hildon-desktop"),
+        QMessageBox::about(this, tr("MohammadAG hildon-desktop (incl. Matans mhd)"),
                            mhd);
     }
 
-void MainWindow::showInstall2()
+void MainWindow::showTest()
 {
-    QString mhd;
-        mhd.append("<h2>Achtung: Nur fr PR1.2</h2>");
-        mhd.append("<p>ber den Link downloaden und manuell installieren.<br/>'dpgk -i hildon-home_0.3.66-2+0m5_armel.deb' im XTerm.");
-        mhd.append(tr("<h1><a href=http://my.arava.co.il/~matan/770/n900/hildon-home_0.3.66-2+0m5_armel.deb>modified-hildon-home</a></h1>"));
+    system("cp /home/user/MyDocs/.images/desktop+/01.png /home/user/.backgrounds/background-1.png && cp /home/user/MyDocs/.images/desktop+/02.png /home/user/.backgrounds/background-2.png && cp /home/user/MyDocs/.images/desktop+/03.png /home/user/.backgrounds/background-3.png && cp /home/user/MyDocs/.images/desktop+/04.png /home/user/.backgrounds/background-4.png && cp /home/user/MyDocs/.images/desktop+/05.png /home/user/.backgrounds/background-5.png && cp /home/user/MyDocs/.images/desktop+/06.png /home/user/.backgrounds/background-6.png && cp /home/user/MyDocs/.images/desktop+/07.png /home/user/.backgrounds/background-7.png && cp /home/user/MyDocs/.images/desktop+/08.png /home/user/.backgrounds/background-8.png && cp /home/user/MyDocs/.images/desktop+/09.png /home/user/.backgrounds/background-9.png");
 
-        QMessageBox::about(this, tr("modified-hildon-home"),
-                           mhd);
     }
 
+
+
 void MainWindow::on_pushButton_clicked()
 {
     QString question;
@@ -119,6 +130,7 @@ void MainWindow::on_pushButton_6_clicked()
                                     QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
     if (reply == QMessageBox::Yes)
                 system("gconftool-2 -s /apps/osso/hildon-desktop/views/active -t list --list-type int [1,2,3,4,5,6]");
+
     else if (reply == QMessageBox::No)
         ;
     else
@@ -176,103 +188,29 @@ void MainWindow::on_pushButton_13_clicked()
         ;
 }
 
+
 void MainWindow::on_pushButton_11_clicked()
 {
 
         QString question;
-        question.append("<p>Haben Sie modified-hildon-home installiert?</p>");
-        question.append("Wenn 'Ja', wird der Hintergrund ber das gconftool eingestellt.<br/>");
-        question.append("Wenn 'Nein' wird der Hintergrund nach '../.backgrounds/' kopiert.");
+        question.append("Sollen die Hintergrnde gesetzt werden?<br/><br/>");
+        question.append("Sie werden aus '../.images/desktop+' nach '../.backgrounds/' kopiert.");
 
         QMessageBox::StandardButton reply;
-        reply = QMessageBox::question(this, tr("Hintergrund fr Desktop 5 setzen:"),
+        reply = QMessageBox::question(this, tr("Hintergrund fr Desktops setzen:"),
                                         question,
                                         QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
         if (reply == QMessageBox::Yes)
-                        system("gconftool-2 -s /apps/osso/hildon-desktop/views/5/bg-image -t string /home/user/MyDocs/.images/desktop+/5.png");
+            system("cp /home/user/MyDocs/.images/desktop+/1.png /home/user/.backgrounds/background-1.png && cp /home/user/MyDocs/.images/desktop+/2.png /home/user/.backgrounds/background-2.png && cp /home/user/MyDocs/.images/desktop+/3.png /home/user/.backgrounds/background-3.png && cp /home/user/MyDocs/.images/desktop+/4.png /home/user/.backgrounds/background-4.png && cp /home/user/MyDocs/.images/desktop+/5.png /home/user/.backgrounds/background-5.png && cp /home/user/MyDocs/.images/desktop+/6.png /home/user/.backgrounds/background-6.png && cp /home/user/MyDocs/.images/desktop+/7.png /home/user/.backgrounds/background-7.png && cp /home/user/MyDocs/.images/desktop+/8.png /home/user/.backgrounds/background-8.png && cp /home/user/MyDocs/.images/desktop+/9.png /home/user/.backgrounds/background-9.png");
+
         else if (reply == QMessageBox::No)
-            system("cp /home/user/MyDocs/.images/desktop+/5.png /home/user/.backgrounds/background-5.png");
+            ;
+
         else
             ;
 
 }
 
-void MainWindow::on_pushButton_12_clicked()
-{
-    QString question;
-    question.append("<p>Haben Sie modified-hildon-home installiert?</p>");
-    question.append("Wenn 'Ja', wird der Hintergrund ber das gconftool eingestellt.<br/>");
-    question.append("Wenn 'Nein' wird der Hintergrund nach '../.backgrounds/' kopiert.");
-
-    QMessageBox::StandardButton reply;
-    reply = QMessageBox::question(this, tr("Hintergrund fr Desktop 6 setzen:"),
-                                    question,
-                                    QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
-    if (reply == QMessageBox::Yes)
-                    system("gconftool-2 -s /apps/osso/hildon-desktop/views/6/bg-image -t string /home/user/MyDocs/.images/desktop+/6.png");
-    else if (reply == QMessageBox::No)
-        system("cp /home/user/MyDocs/.images/desktop+/6.png /home/user/.backgrounds/background-6.png");
-    else
-        ;
-
-}
-void MainWindow::on_pushButton_7_clicked()
-{
-    QString question;
-    question.append("<p>Haben Sie modified-hildon-home installiert?</p>");
-    question.append("Wenn 'Ja', wird der Hintergrund ber das gconftool eingestellt.<br/>");
-    question.append("Wenn 'Nein' wird der Hintergrund nach '../.backgrounds/' kopiert.");
-
-    QMessageBox::StandardButton reply;
-    reply = QMessageBox::question(this, tr("Hintergrund fr Desktop 7 setzen:"),
-                                    question,
-                                    QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
-    if (reply == QMessageBox::Yes)
-                    system("gconftool-2 -s /apps/osso/hildon-desktop/views/7/bg-image -t string /home/user/MyDocs/.images/desktop+/7.png");
-    else if (reply == QMessageBox::No)
-        system("cp /home/user/MyDocs/.images/desktop+/7.png /home/user/.backgrounds/background-7.png");
-    else
-        ;
-}
-
-void MainWindow::on_pushButton_8_clicked()
-{
-    QString question;
-    question.append("<p>Haben Sie modified-hildon-home installiert?</p>");
-    question.append("Wenn 'Ja', wird der Hintergrund ber das gconftool eingestellt.<br/>");
-    question.append("Wenn 'Nein' wird der Hintergrund nach '../.backgrounds/' kopiert.");
-
-    QMessageBox::StandardButton reply;
-    reply = QMessageBox::question(this, tr("Hintergrund fr Desktop 8 setzen:"),
-                                    question,
-                                    QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
-    if (reply == QMessageBox::Yes)
-                    system("gconftool-2 -s /apps/osso/hildon-desktop/views/8/bg-image -t string /home/user/MyDocs/.images/desktop+/8.png");
-    else if (reply == QMessageBox::No)
-        system("cp /home/user/MyDocs/.images/desktop+/8.png /home/user/.backgrounds/background-8.png");
-    else
-        ;
-}
-
-void MainWindow::on_pushButton_9_clicked()
-{
-    QString question;
-    question.append("<p>Haben Sie modified-hildon-home installiert?</p>");
-    question.append("Wenn 'Ja', wird der Hintergrund ber das gconftool eingestellt.<br/>");
-    question.append("Wenn 'Nein' wird der Hintergrund nach '../.backgrounds/' kopiert.");
-
-    QMessageBox::StandardButton reply;
-    reply = QMessageBox::question(this, tr("Hintergrund fr Desktop 9 setzen:"),
-                                    question,
-                                    QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
-    if (reply == QMessageBox::Yes)
-                    system("gconftool-2 -s /apps/osso/hildon-desktop/views/9/bg-image -t string /home/user/MyDocs/.images/desktop+/9.png");
-    else if (reply == QMessageBox::No)
-        system("cp /home/user/MyDocs/.images/desktop+/9.png /home/user/.backgrounds/background-9.png");
-    else
-        ;
-}
-
 void MainWindow::on_pushButton_10_clicked()
 {
     QString question;
