@@ -21,11 +21,7 @@ private:
 private slots:
     void on_pushButton_13_clicked();
     void on_pushButton_10_clicked();
-    void on_pushButton_9_clicked();
-    void on_pushButton_8_clicked();
-    void on_pushButton_12_clicked();
     void on_pushButton_11_clicked();
-    void on_pushButton_7_clicked();
     void on_pushButton_4_clicked();
     void on_pushButton_5_clicked();
     void on_pushButton_6_clicked();
@@ -36,10 +32,7 @@ public slots:
     void showHelp();
     void showAbout();
     void showInstall();
-    void showInstall2();
-
-
-
+    void showTest();
 
 };
 
